@@ -35,7 +35,7 @@
 #define HAVE_IPV6 1
 #define HAVE_ZLIB 1
 #define HAVE_I18N 1
-/* #undef ZNC_HAVE_ARGON */
+#define ZNC_HAVE_ARGON 1
 #define CSOCK_USE_POLL 1
 
 #define HAVE_GETOPT_LONG 1
